==> amarok-1.83.tar.bz2: amarok-1.83/src/dbus/RootDBusHandler.h <==
/******************************************************************************
 * Copyright (C) 2008 Ian Monroe <ian@monroe.nu>                              *
 *           (C) 2008 Peter ZHOU <peterzhoulei@gmail.com>                     *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License as             *
 * published by the Free Software Foundation; either version 2 of             *
 * the License, or (at your option) any later version.                        *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.      *
 ******************************************************************************/

#ifndef ROOT_DBUS_HANDLER_H
#define ROOT_DBUS_HANDLER_H

#include <QObject>

namespace Amarok
{
    class RootDBusHandler : public QObject
    {
        Q_OBJECT

        public:
            RootDBusHandler();

            virtual QString Identity();
            virtual void Quit();
            virtual float MprisVersion();
    };
}

#endif

==> amarok-1.86.tar.bz2: amarok-1.86/src/dbus/RootDBusHandler.h <==
/******************************************************************************
 * Copyright (C) 2008 Ian Monroe <ian@monroe.nu>                              *
 *           (C) 2008 Peter ZHOU <peterzhoulei@gmail.com>                     *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License as             *
 * published by the Free Software Foundation; either version 2 of             *
 * the License, or (at your option) any later version.                        *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.      *
 ******************************************************************************/

#ifndef ROOT_DBUS_HANDLER_H
#define ROOT_DBUS_HANDLER_H

#include <QObject>
#include <QDBusArgument>

struct Version
{
    int major;
    int minor;
};

Q_DECLARE_METATYPE(Version);

// Marshall the DBusVersion data into a D-BUS argument
QDBusArgument &operator<<(QDBusArgument &argument, const Version &version);
// Retrieve the DBusVersion data from the D-BUS argument
const QDBusArgument &operator>>(const QDBusArgument &argument, Version &version);

namespace Amarok
{
    class RootDBusHandler : public QObject
    {
        Q_OBJECT

        public:
            RootDBusHandler();
            QString Identity();
            void Quit();
            Version MprisVersion();
    };
}

#endif
